﻿using DemoProb.Classes;
using DemoProb.WindowW;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DemoProb.Pages
{
    /// <summary>
    /// Логика взаимодействия для MainPage.xaml
    /// </summary>
    
    public partial class MainPage : Page
    {
        List<Service> listBoxItems = BaseClass.BaseSchool.Service.ToList();
        List<Service> listSearchItems = BaseClass.BaseSchool.Service.ToList();
        //string a = Color.FromRgb(231, 250, 191).ToString();
        public MainPage()
        {
            InitializeComponent();
            ListServices.ItemsSource = listBoxItems;
            CountText();
        }

        private void Border_Loaded(object sender, RoutedEventArgs e)
        {
            Grid brd = (Grid)sender;
            Service servic = BaseClass.BaseSchool.Service.FirstOrDefault(x => x.ID.ToString() == brd.Uid);

            if (servic.Discount != null && servic.Discount > 0) brd.Background = (Brush)(new BrushConverter().ConvertFrom("#FFE7FABF"));
        }
        private void InfoService_Loaded(object sender, RoutedEventArgs e)
        {
            TextBlock tb = (TextBlock)sender;
            int id = Convert.ToInt32(tb.Uid);
            Service services = BaseClass.BaseSchool.Service.FirstOrDefault(x=>x.ID == id);
            foreach (Service service in listBoxItems)
            {
                if(services.Discount == null)
                {
                    tb.Text = $"{(int)services.Cost} рублей за {services.DurationInSeconds/60} минут";
                }
                else
                {
                    tb.Text = $"{(int)((double)services.Cost - ((double)services.Cost * services.Discount))} рублей за {services.DurationInSeconds/60} минут";
                }
            }
        }

        private void Discount_Loaded(object sender, RoutedEventArgs e)
        {
            TextBlock tb = (TextBlock)sender;
            int id = Convert.ToInt32(tb.Uid);
            Service services = BaseClass.BaseSchool.Service.FirstOrDefault(x => x.ID == id);
            foreach (Service service in listBoxItems)
            {
                if (services.Discount != null)
                {
                    tb.Text = $"* скидка {services.Discount * 100}%";

                }
                else tb.Text = "";
            }
        }

        private void CostNoDiscount_Loaded(object sender, RoutedEventArgs e)
        {
            TextBlock tb = (TextBlock)sender;
            int id = Convert.ToInt32(tb.Uid);
            Service services = BaseClass.BaseSchool.Service.FirstOrDefault(x => x.ID == id);
            foreach (Service service in listBoxItems)
            {
                if (services.Discount != null)
                {
                    tb.Text = $"{(int)services.Cost} ";
                    tb.TextDecorations = TextDecorations.Strikethrough;
                }
                else tb.Text = "";
            }
        }

        private void Edit_Click(object sender, RoutedEventArgs e)
        {
            Button but = (Button)sender;
            Service serviceItem = BaseClass.BaseSchool.Service.FirstOrDefault(x => x.ID.ToString() == but.Uid);
            CreateWindow cw = new CreateWindow(serviceItem);
            cw.Show();
            cw.Closed += Cw_Closed;
            SortCost1.IsChecked = false;
            SortCost2.IsChecked = false;
            Filter.SelectedItem = All;
        }

        private void Cw_Closed(object sender, EventArgs e)
        {
            ListServices.ItemsSource = null;
            ListServices.ItemsSource = BaseClass.BaseSchool.Service.ToList();
        }

        private void Delete_Click(object sender, RoutedEventArgs e)
        {
            MessageBoxResult res = MessageBox.Show("Действительно удалить услугу?", "Подтверждение", MessageBoxButton.YesNo, MessageBoxImage.Question);
            switch (res)
            {
                case MessageBoxResult.Yes:
                    {
                        Button but = (Button)sender;
                        Service serviceItem = BaseClass.BaseSchool.Service.FirstOrDefault(x => x.ID.ToString() == but.Uid);
                        List<ClientService> clientServices = BaseClass.BaseSchool.ClientService.ToList();
                        int count = 0;
                        foreach(ClientService cServ in clientServices)
                        {
                            if(cServ.ServiceID == serviceItem.ID)
                            {
                                MessageBox.Show("На данную услугу еще остались записи. Услуга не может быть удалена", "Уведомление", MessageBoxButton.OK, MessageBoxImage.Information);
                                count++;
                                break;
                            }
                        }
                        if(count == 0)
                        {
                            BaseClass.BaseSchool.Service.Remove(serviceItem);
                            BaseClass.BaseSchool.SaveChanges();
                            MessageBox.Show("Услуга удалена", "Уведомление", MessageBoxButton.OK, MessageBoxImage.Information);
                            ListServices.ItemsSource = null;
                            ListServices.ItemsSource = BaseClass.BaseSchool.Service.ToList();
                            CountText();
                        }
                    }
                    break;
                case MessageBoxResult.No:
                    break;
            }
        }

        private void SortCost1_Checked(object sender, RoutedEventArgs e)
        {
            ListServices.ItemsSource = listBoxItems.OrderBy(x => x.Cost).Reverse();
        }

        private void SortCost2_Checked(object sender, RoutedEventArgs e)
        {
            ListServices.ItemsSource = listBoxItems.OrderBy(x => x.Cost);
        }

        private void Edit_Loaded(object sender, RoutedEventArgs e)
        {
            Button btnEd = (Button)sender;
            if ((bool)Application.Current.Properties["admin"] == true)
                btnEd.Visibility = Visibility.Visible;
            else btnEd.Visibility = Visibility.Collapsed;
        }

        private void Delete_Loaded(object sender, RoutedEventArgs e)
        {
            Button btnDel = (Button)sender;
            if ((bool)Application.Current.Properties["admin"] == true)
                btnDel.Visibility = Visibility.Visible;
            else btnDel.Visibility = Visibility.Collapsed;
        }

        private void Filter_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(Filter.SelectedItem == All)
            {
                listBoxItems = listSearchItems;
            }
            else if(Filter.SelectedItem == oneFilter)
            {
                listBoxItems = listSearchItems.Where(x => x.Discount < 0.05).ToList();
            }
            else if (Filter.SelectedItem == twoFilter)
            {
                listBoxItems = listSearchItems.Where(x => x.Discount >= 0.05 && x.Discount < 0.15).ToList();
            }
            else if (Filter.SelectedItem == threeFilter)
            {
                listBoxItems = listSearchItems.Where(x => x.Discount >= 0.15 && x.Discount < 0.30).ToList();
            }
            else if (Filter.SelectedItem == fourFilter)
            {
                listBoxItems = listSearchItems.Where(x => x.Discount >= 0.30 && x.Discount < 0.70).ToList();
            }
            else if (Filter.SelectedItem == fiveFilter)
            {
                listBoxItems = listSearchItems.Where(x => x.Discount >= 0.70 && x.Discount < 0.100).ToList();
            }
            SortCost1.IsChecked = false;
            SortCost2.IsChecked = false;
            ListServices.ItemsSource = listBoxItems;
            CountText();
        }

        private void ThrowOff_Click(object sender, RoutedEventArgs e)
        {
            listBoxItems = BaseClass.BaseSchool.Service.ToList();
            SortCost1.IsChecked = false;
            SortCost2.IsChecked = false;
            Filter.SelectedItem = All;
            ListServices.ItemsSource = listBoxItems;
            Search.Text = string.Empty;
            CountText();
        }
        private void CountText()
        {
            listBoxItems = BaseClass.BaseSchool.Service.ToList();
            Count.Text = $"{listBoxItems.Count} из {BaseClass.BaseSchool.Service.Count()}";
        }
        private void Search_TextChanged(object sender, TextChangedEventArgs e)
        {
            SortCost1.IsChecked = false;
            SortCost2.IsChecked = false;
            Filter.SelectedItem = All;
            if (Search.Text.Length > 0)
                listSearchItems = BaseClass.BaseSchool.Service.Where(x => x.Title.ToLower().Contains(Search.Text.ToLower())).ToList();
            else listSearchItems = BaseClass.BaseSchool.Service.ToList();
            listBoxItems = listSearchItems;
            ListServices.ItemsSource = listBoxItems;
            CountText();
        }

        private void addService_Click(object sender, RoutedEventArgs e)
        {
            AddWindow wind = new AddWindow();
            wind.Show();
            wind.Closed += Wind_Closed;
        }

        private void Wind_Closed(object sender, EventArgs e)
        {
            ListServices.ItemsSource = null;
            ListServices.ItemsSource = BaseClass.BaseSchool.Service.ToList();
            CountText();
        }

        private void addService_Loaded(object sender, RoutedEventArgs e)
        {
            Button btnDel = (Button)sender;
            if ((bool)Application.Current.Properties["admin"] == true)
                btnDel.Visibility = Visibility.Visible;
            else btnDel.Visibility = Visibility.Collapsed;
        }

        private void Record_Click(object sender, RoutedEventArgs e)
        {
            Button btnRed = (Button)sender;
            RecordForService wind = new RecordForService(btnRed.Uid);
            wind.Show();
        }

        private void Record_Loaded(object sender, RoutedEventArgs e)
        {
            Button btnRec = (Button)sender;
            if ((bool)Application.Current.Properties["admin"] == true)
                btnRec.Visibility = Visibility.Collapsed;
            else btnRec.Visibility = Visibility.Visible;
        }
    }
}
